Crate vial_shared

Crate vial_shared 

Structs

CreateSecretRequest
Sent to the server when creating a new secret
EncryptedPayload
Received via HTTPS from the server then decrypted to Payload struct
FullSecret
FullSecretV1
Payload
Once the bytes gets decrypted, should be deserialized to this struct. Similarly, before encrypting, this struct is serialized to bytes.
SecretFile
SecretFileV1
SecretId
Gets returned by the server when creating a new secret

Functions

sanitize_filename
Helper function to sanitize a filename from potentially unsafe characters