pub struct Payload {
pub version: u8,
pub payload: Vec<u8>,
}Expand description
Once the bytes gets decrypted, should be deserialized to this struct. Similarly, before encrypting, this struct is serialized to bytes.
After deserializing, the bytes can be deserialized to FullSecretV1 struct.
Similarly, payload is generated from the serialized FullSecretV1 struct.
Fields
version: u8payload: Vec<u8>Implementations