Structs
- Create
Secret Request - Sent to the server when creating a new secret
- Encrypted
Payload - Received via HTTPS from the server then decrypted to Payload struct
- Full
Secret - Full
Secret V1 - Payload
- Once the bytes gets decrypted, should be deserialized to this struct. Similarly, before encrypting, this struct is serialized to bytes.
- Secret
File - Secret
File V1 - Secret
Id - Gets returned by the server when creating a new secret
Functions
- sanitize_
filename - Helper function to sanitize a filename from potentially unsafe characters